@@ -5,7 +5,7 @@ use warnings;
 
 # ABSTRACT: A CSV converting processor
 
-our $VERSION = '1.111510'; # VERSION
+our $VERSION = '1.111560'; # VERSION
 
 use Moose;
 extends 'DataFlow::Proc::Converter';
@@ -78,24 +78,22 @@ has '+converter_subs' => (
         my $self = shift;
         return {
             'CONVERT_TO' => sub {
-                my $data = shift;
-                my @res  = ();
+                my @res = ();
                 if ( $self->header_wanted ) {
                     $self->header_wanted(0);
                     push @res, $self->_combine( $self->header );
                 }
 
-                push @res, $self->_combine($data);
+                push @res, $self->_combine($_);
                 return @res;
             },
             'CONVERT_FROM' => sub {
-                my $csv_line = shift;
                 if ( $self->header_wanted ) {
                     $self->header_wanted(0);
-                    $self->header( $self->_parse($csv_line) );
+                    $self->header( $self->_parse($_) );
                     return;
                 }
-                return $self->_parse($csv_line);
+                return $self->_parse($_);
             },
         };
     },
@@ -118,7 +116,19 @@ DataFlow::Proc::CSV - A CSV converting processor
 
 =head1 VERSION
 
-version 1.111510
+version 1.111560
+
+=head1 SEE ALSO
+
+Please see those modules/websites for more information related to this module.
+
+=over 4
+
+=item *
+
+L<DataFlow|DataFlow>
+
+=back
 
 =head1 AUTHOR
 
@@ -136,18 +146,7 @@ the same terms as the Perl 5 programming language system itself.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://github.com/russoz/DataFlow/issues>.
-
-=head1 AVAILABILITY
-
-The latest version of this module is available from the Comprehensive Perl
-Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
-site near you, or see L<http://search.cpan.org/dist/DataFlow/>.
-
-The development version lives at L<http://github.com/russoz/DataFlow>
-and may be cloned from L<git://github.com/russoz/DataFlow.git>.
-Instead of sending patches, please fork this project using the standard
-git and github infrastructure.
+L<http://rt.cpan.org>.
 
 =head1 DISCLAIMER OF WARRANTY
 
