@@ -5,7 +5,7 @@ use warnings;
 
 # ABSTRACT: A HTML filtering processor
 
-our $VERSION = '1.111510'; # VERSION
+our $VERSION = '1.111560'; # VERSION
 
 use Moose;
 extends 'DataFlow::Proc';
@@ -47,9 +47,7 @@ has '+p' => (
         my $self = shift;
 
         my $proc = sub {
-            my $item = shift;
-
-            my $html = HTML::TreeBuilder::XPath->new_from_content($item);
+            my $html = HTML::TreeBuilder::XPath->new_from_content($_);
 
             #warn 'xpath is built';
             #warn 'values if VALUES';
@@ -91,7 +89,7 @@ DataFlow::Proc::HTMLFilter - A HTML filtering processor
 
 =head1 VERSION
 
-version 1.111510
+version 1.111560
 
 =head1 SYNOPSIS
 
@@ -174,6 +172,18 @@ On the other hand, by keeping C<ref_result> as 0 (false), one HTML item
 may produce any number of items as result,
 i.e. it is a one-to-many mapping.
 
+=head1 SEE ALSO
+
+Please see those modules/websites for more information related to this module.
+
+=over 4
+
+=item *
+
+L<DataFlow|DataFlow>
+
+=back
+
 =head1 AUTHOR
 
 Alexei Znamensky <russoz@cpan.org>
@@ -190,18 +200,7 @@ the same terms as the Perl 5 programming language system itself.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://github.com/russoz/DataFlow/issues>.
-
-=head1 AVAILABILITY
-
-The latest version of this module is available from the Comprehensive Perl
-Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
-site near you, or see L<http://search.cpan.org/dist/DataFlow/>.
-
-The development version lives at L<http://github.com/russoz/DataFlow>
-and may be cloned from L<git://github.com/russoz/DataFlow.git>.
-Instead of sending patches, please fork this project using the standard
-git and github infrastructure.
+L<http://rt.cpan.org>.
 
 =head1 DISCLAIMER OF WARRANTY
 
