@@ -5,7 +5,7 @@ use warnings;
 
 # ABSTRACT: A JSON converting processor
 
-our $VERSION = '1.111510'; # VERSION
+our $VERSION = '1.111560'; # VERSION
 
 use Moose;
 extends 'DataFlow::Proc::Converter';
@@ -43,12 +43,10 @@ has '+converter_subs' => (
         my $self = shift;
         return {
             'CONVERT_TO' => sub {
-                my $data = shift;
-                return $self->converter->to_json($data);
+                return $self->converter->to_json($_);
             },
             'FROM_JSON' => sub {
-                my $json = shift;
-                return $self->converter->from_json($json);
+                return $self->converter->from_json($_);
             },
         };
     },
@@ -71,7 +69,19 @@ DataFlow::Proc::JSON - A JSON converting processor
 
 =head1 VERSION
 
-version 1.111510
+version 1.111560
+
+=head1 SEE ALSO
+
+Please see those modules/websites for more information related to this module.
+
+=over 4
+
+=item *
+
+L<DataFlow|DataFlow>
+
+=back
 
 =head1 AUTHOR
 
@@ -89,18 +99,7 @@ the same terms as the Perl 5 programming language system itself.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://github.com/russoz/DataFlow/issues>.
-
-=head1 AVAILABILITY
-
-The latest version of this module is available from the Comprehensive Perl
-Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
-site near you, or see L<http://search.cpan.org/dist/DataFlow/>.
-
-The development version lives at L<http://github.com/russoz/DataFlow>
-and may be cloned from L<git://github.com/russoz/DataFlow.git>.
-Instead of sending patches, please fork this project using the standard
-git and github infrastructure.
+L<http://rt.cpan.org>.
 
 =head1 DISCLAIMER OF WARRANTY
 
