@@ -5,7 +5,7 @@ use warnings;
 
 # ABSTRACT: A No-Op processor: input data is passed unmodified to the output
 
-our $VERSION = '1.111510'; # VERSION
+our $VERSION = '1.111560'; # VERSION
 
 use Moose;
 extends 'DataFlow::Proc';
@@ -15,7 +15,7 @@ use namespace::autoclean;
 has '+process_into' => ( 'default' => 0, );
 has '+p' => (
     'default' => sub {
-        return sub { $_[0]; }
+        return sub { $_ }
     },
 );
 
@@ -35,7 +35,7 @@ DataFlow::Proc::NOP - A No-Op processor: input data is passed unmodified to the
 
 =head1 VERSION
 
-version 1.111510
+version 1.111560
 
 =head1 SYNOPSIS
 
@@ -58,6 +58,18 @@ This class is more useful as parent class than by itself.
 The interface for C<DataFlow::Proc::NOP> is the same of
 C<DataFlow::Proc>.
 
+=head1 SEE ALSO
+
+Please see those modules/websites for more information related to this module.
+
+=over 4
+
+=item *
+
+L<DataFlow|DataFlow>
+
+=back
+
 =head1 AUTHOR
 
 Alexei Znamensky <russoz@cpan.org>
@@ -74,18 +86,7 @@ the same terms as the Perl 5 programming language system itself.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://github.com/russoz/DataFlow/issues>.
-
-=head1 AVAILABILITY
-
-The latest version of this module is available from the Comprehensive Perl
-Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
-site near you, or see L<http://search.cpan.org/dist/DataFlow/>.
-
-The development version lives at L<http://github.com/russoz/DataFlow>
-and may be cloned from L<git://github.com/russoz/DataFlow.git>.
-Instead of sending patches, please fork this project using the standard
-git and github infrastructure.
+L<http://rt.cpan.org>.
 
 =head1 DISCLAIMER OF WARRANTY
 
