@@ -5,7 +5,7 @@ use warnings;
 
 # ABSTRACT: A role that defines how to use proc-handlers
 
-our $VERSION = '1.111510'; # VERSION
+our $VERSION = '1.111560'; # VERSION
 
 use Moose::Role;
 
@@ -32,10 +32,12 @@ sub apply {
     my ( $self, $p, $item ) = @_;
     my $type = _param_type($item);
 
-    return
+    my $handler =
       exists $self->handlers->{$type}
-      ? $self->handlers->{$type}->( $p, $item )
-      : $self->default_handler->( $p, $item );
+      ? $self->handlers->{$type}
+      : $self->default_handler;
+
+    return $handler->( $p, $item );
 }
 
 sub _param_type {
@@ -44,18 +46,29 @@ sub _param_type {
     return $r ? $r : 'SVALUE';
 }
 
+sub _make_apply_ref {
+    my ( $self, $p ) = @_;
+    return sub { $self->apply( $p, $_ ) };
+}
+
 sub _nop_handle {    ## no critic
     return $_[1];
 }
 
+sub _run_p {
+    my ( $p, $item ) = @_;
+    local $_ = $item;
+    return $p->();
+}
+
 sub _handle_svalue {
     my ( $p, $item ) = @_;
-    return $p->($item);
+    return _run_p( $p, $item );
 }
 
 sub _handle_scalar_ref {
     my ( $p, $item ) = @_;
-    my $r = $p->($$item);
+    my $r = _run_p( $p, $$item );
     return \$r;
 }
 
@@ -63,24 +76,19 @@ sub _handle_array_ref {
     my ( $p, $item ) = @_;
 
     #use Data::Dumper; warn 'handle_array_ref :: item = ' . Dumper($item);
-    my @r = map { $p->($_) } @{$item};
+    my @r = map { _run_p( $p, $_ ) } @{$item};
     return [@r];
 }
 
 sub _handle_hash_ref {
     my ( $p, $item ) = @_;
-    my %r = map { $_ => $p->( $item->{$_} ) } keys %{$item};
+    my %r = map { $_ => _run_p( $p, $item->{$_} ) } keys %{$item};
     return {%r};
 }
 
 sub _handle_code_ref {
     my ( $p, $item ) = @_;
-    return sub { $p->( $item->() ) };
-}
-
-sub _make_apply_ref {
-    my ( $self, $p ) = @_;
-    return sub { $self->apply( $p, $_[0] ) };
+    return sub { _run_p( $p, $item->() ) };
 }
 
 1;
@@ -98,12 +106,24 @@ DataFlow::Role::ProcPolicy - A role that defines how to use proc-handlers
 
 =head1 VERSION
 
-version 1.111510
+version 1.111560
 
 =head2 apply P ITEM
 
 Applies the policy using function P and input data ITEM.
 
+=head1 SEE ALSO
+
+Please see those modules/websites for more information related to this module.
+
+=over 4
+
+=item *
+
+L<DataFlow|DataFlow>
+
+=back
+
 =head1 AUTHOR
 
 Alexei Znamensky <russoz@cpan.org>
@@ -120,18 +140,7 @@ the same terms as the Perl 5 programming language system itself.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://github.com/russoz/DataFlow/issues>.
-
-=head1 AVAILABILITY
-
-The latest version of this module is available from the Comprehensive Perl
-Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
-site near you, or see L<http://search.cpan.org/dist/DataFlow/>.
-
-The development version lives at L<http://github.com/russoz/DataFlow>
-and may be cloned from L<git://github.com/russoz/DataFlow.git>.
-Instead of sending patches, please fork this project using the standard
-git and github infrastructure.
+L<http://rt.cpan.org>.
 
 =head1 DISCLAIMER OF WARRANTY
 
