@@ -5,7 +5,7 @@ use warnings;
 
 # ABSTRACT: Type definitions for DataFlow
 
-our $VERSION = '1.111510'; # VERSION
+our $VERSION = '1.111560'; # VERSION
 
 use MooseX::Types -declare => [
     qw(ProcessorChain Encoder Decoder HTMLFilterTypes),
@@ -79,7 +79,7 @@ coerce 'ProcessorChain' => from 'ArrayRef' => via {
             }
             elsif ( $proc->isa('DataFlow') ) {
                 push @res,
-                  DataFlow::Proc->new( p => sub { $proc->process(@_) } );
+                  DataFlow::Proc->new( p => sub { $proc->process($_) } );
             }
             else {
                 die q{Invalid object (} . $ref
@@ -144,7 +144,19 @@ DataFlow::Types - Type definitions for DataFlow
 
 =head1 VERSION
 
-version 1.111510
+version 1.111560
+
+=head1 SEE ALSO
+
+Please see those modules/websites for more information related to this module.
+
+=over 4
+
+=item *
+
+L<DataFlow|DataFlow>
+
+=back
 
 =head1 AUTHOR
 
@@ -162,18 +174,7 @@ the same terms as the Perl 5 programming language system itself.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://github.com/russoz/DataFlow/issues>.
-
-=head1 AVAILABILITY
-
-The latest version of this module is available from the Comprehensive Perl
-Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
-site near you, or see L<http://search.cpan.org/dist/DataFlow/>.
-
-The development version lives at L<http://github.com/russoz/DataFlow>
-and may be cloned from L<git://github.com/russoz/DataFlow.git>.
-Instead of sending patches, please fork this project using the standard
-git and github infrastructure.
+L<http://rt.cpan.org>.
 
 =head1 DISCLAIMER OF WARRANTY
 
